@@ -1,10 +1,10 @@
 package String::Validator::Phone::NANP;
-$String::Validator::Phone::NANP::VERSION = '2.01'; # TRIAL
+$String::Validator::Phone::NANP::VERSION = '2.04'; # TRIAL
 use 5.008;
 use strict;
 use warnings;
 use String::Validator::Common 2.01;
-use Number::Phone ;
+use Number::Phone 3.9001;
 
 # ABSTRACT: Validate North American Phone Numbers
 
@@ -149,7 +149,7 @@ String::Validator::Phone::NANP - Validate North American Phone Numbers
 
 =head1 VERSION
 
-version 2.01
+version 2.04
 
 =head1 SYNOPSIS
 
